SmartLinksClient class
Properties
- config → SmartLinksConfig
-
no setter
- dioV1 → Dio
-
no setter
- dioV2 → Dio
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dioForBaseUrl(
String baseUrl) → Dio -
getV1<
T> (String path, {Map< String, dynamic> ? queryParameters, Map<String, dynamic> ? headers}) → Future<Response< T> > -
getV2<
T> (String path, {Map< String, dynamic> ? queryParameters, Map<String, dynamic> ? headers}) → Future<Response< T> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postV1<
T> (String path, {Object? data, Map< String, dynamic> ? headers}) → Future<Response< T> > -
postV2<
T> (String path, {Object? data, Map< String, dynamic> ? headers}) → Future<Response< T> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → SmartLinksClient
-
no setter
- isReady → bool
-
no setter
Static Methods
-
create(
SmartLinksConfig config) → SmartLinksClient -
resetForTest(
) → void - Resets singleton state. For tests only.